
## 1.1.3

Allow protocol header to be configured with `HSTS_PROTOCOL_HEADER` environment
variable.

## 1.1.2

Also secure ``request.host_url``.

## 1.1

Update docs and strip out unnecessary settings.

## 1.0

Extracted into standalone package from `pyramid_weblayer.hsts`.
